@@ -33,7 +33,7 @@ class OverwritePermission:
     allow: int
     deny: int
 
-    def __init__(self, *, role_id: int, allow: int, deny: int):
+    def __init__(self, *, role_id: int, allow: int, deny: int, **_):
         self.role_id = role_id
         self.allow = allow
         self.deny = deny
@@ -44,7 +44,7 @@ class UserPermission:
     allow: int
     deny: int
 
-    def __init__(self, *, user: User, allow: int, deny: int):
+    def __init__(self, *, user: User, allow: int, deny: int, **_):
         self.user = user
         self.allow = allow
         self.deny = deny
@@ -154,15 +154,15 @@ class PublicChannel(Channel, ABC):
         return self.permission
 
     async def create_user_permission(self, target: Union[User, str]):
-        t = 'user_id' 
-        v = target.id if isinstance(target,User) else target
+        t = 'user_id'
+        v = target.id if isinstance(target, User) else target
         d = await self.gate.exec_req(api.ChannelRole.create(channel_id=self.id, type=t, value=v))
         self.permission.loaded = False
         return d
-    
-    async def update_user_permission(self, target: Union[User, str],allow: int = 0, deny: int = 0) -> Role:
+
+    async def update_user_permission(self, target: Union[User, str], allow: int = 0, deny: int = 0) -> Role:
         t = 'user_id'
-        v = target.id if isinstance(target,User) else target
+        v = target.id if isinstance(target, User) else target
         return await self.gate.exec_req(
             api.ChannelRole.update(channel_id=self.id, type=t, value=v, allow=allow, deny=deny))
 
@@ -170,17 +170,17 @@ class PublicChannel(Channel, ABC):
         t = 'user_id'
         v = target.id if isinstance(target, User) else target
         return await self.gate.exec_req(api.ChannelRole.delete(channel_id=self.id, type=t, value=v))
-    
+
     async def create_role_permission(self, target: Union[Role, str]):
-        t = 'role_id' 
-        v = target.id if isinstance(target,Role) else target
+        t = 'role_id'
+        v = target.id if isinstance(target, Role) else target
         d = await self.gate.exec_req(api.ChannelRole.create(channel_id=self.id, type=t, value=v))
         self.permission.loaded = False
         return d
 
-    async def update_role_permission(self, target: Union[Role, str],allow: int = 0, deny: int = 0) -> Role:
+    async def update_role_permission(self, target: Union[Role, str], allow: int = 0, deny: int = 0) -> Role:
         t = 'role_id'
-        v = target.id if isinstance(target,Role) else target
+        v = target.id if isinstance(target, Role) else target
         return await self.gate.exec_req(
             api.ChannelRole.update(channel_id=self.id, type=t, value=v, allow=allow, deny=deny))
 
